末代皇帝 (豆瓣)
Description: 末代皇帝电影简介和剧情介绍,末代皇帝影评、图片、预告片、影讯、论坛、在线购票
Keywords: 末代皇帝,The Last Emperor,末代皇帝影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.27豆瓣电影Top250

# 末代皇帝 The Last Emperor (1987)

导演: 贝纳尔多·贝托鲁奇
编剧: 贝纳尔多·贝托鲁奇 / 马克·派普罗
主演: 尊龙 / 陈冲 / 邬君梅 / 彼得·奥图尔 / 英若诚 / 吴涛 / 黄自强 / 丹尼斯·邓 / 坂本龙一 / 马吉·汉 / 里克·扬 / 田川洋行 / 苟杰德 / 理查德·吴 / 皱缇格 / 陈凯歌 / 卢燕 / 区亨利 / 陈述 / 鲍皓昕 / 黄文捷 / 邵茹贞 / 亨利·基 / 张良斌 / 梁冬 / 康斯坦丁·格雷戈里 / 黄汉琪 / 王涛 / 宋怀桂 / 蔡鸿翔 / 程淑艳 / 张天民
类型: 剧情 / 传记 / 历史
制片国家/地区: 英国 / 意大利 / 中国大陆 / 法国
语言: 英语 / 汉语普通话 / 日语
上映日期: 1987-10-04(东京国际电影节) / 1987-10-23(意大利)
片长: 163分钟 / 219分钟 (电视版)
又名: 末代皇帝溥仪(港)
IMDb: tt0093389
豆瓣评分
引用
9.3
824503人评价
5星
70.2%
4星
25.5%
3星
4.0%
2星
0.3%
1星
0.1%
好于 99% 历史片
好于 99% 传记片
想看 看过
评价:
推荐

## 末代皇帝的剧情简介 · · · · · ·

溥仪（尊龙 饰）的一生在电影中娓娓道来。他从三岁起登基，年幼的眼光中只有大臣身上的一只蝈蝈，江山在他心中只是一个不明所以的名词。长大了，他以为可以变革，却被太监一把火烧了朝廷账本。他以为自己是大清江山的主人，却做了日本人的傀儡。
解放后，他坐上了从苏联回来的火车，身边是押送监视他的解放军。他猜测自己难逃一死，便躲在狭小的卫生间里，割脉自杀。然而他没有死在火车上，命运的嘲笑还在等着他。文革的风风雨雨，在他身上留下了斑斑伤痕。 ©豆瓣

## 末代皇帝的演职员 · · · · · · ( 全部 59 )

- 贝纳尔多·贝托鲁奇 导演
- 尊龙 饰 溥仪
- 陈冲 饰 婉容
- 邬君梅 饰 文绣
- 彼得·奥图尔 饰 庄士敦
- 英若诚 饰 监狱长

## 末代皇帝的视频和图片 ······ ( 预告片3 | 视频评论2 · 添加 | 图片1836 · 添加 )

## 末代皇帝的获奖情况 · · · · · · ( 全部 )

- 第60届奥斯卡金像奖
- 最佳影片
- 杰瑞米·托马斯

- 第12届日本电影学院奖
- 最佳外语片

- 第7届中国电影金鸡奖
- 最佳道具(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  为奴十二年

  公民凯恩

  至暗时刻

  国王的演讲

  飞行家

  茶馆

  模仿游戏

  社交网络

  美丽心灵

  波西米亚狂想曲

我要写短评

## 末代皇帝的短评 · · · · · · ( 全部 171380 条 )

热门 / 最新 / 好友

### 7079 有用 托尼·王大拿 看过 2011-03-21 16:43:30

尽管看一群中国人在屏幕上讲英语很是奇怪，但不能否认这是部出色的电影：它与国家无关，与王朝无关，这只是一个渴望自由却不得的人的编年史；"门"的意象被反复提及，寓意溥仪被禁闭的一生；贝托鲁奇娴熟的运镜，要人命的广角自然光，美妙的配乐。

### 8432 有用 Over5 看过 2007-02-24 00:14:41

有史以来一部最地道最出色的中国电影，居然，Made By Italian～

### 9432 有用 单线程青年 看过 2008-03-24 09:06:17

不偏袒的好片儿！一个进自己原来的宫殿还要买票的皇帝。

### 4253 有用 疯眼穆迪 看过 2008-04-09 16:30:40

我觉得对于一个外国人拍的中国人物传记来说，它最可贵的不是那些对比强烈的色彩和镜头，而是他的态度，他对这个人物的理解，他并没有评判什么但是他把故事默默地摆在那里，到结束，你会一时觉得心情复杂，而且更重要的一点是，电影里不仅仅塑造了溥仪一个角色，而是通过细节也讲述了围绕着他的一些人的沧桑，这对于一个外国人来说，我觉得异常珍贵。虽然还是有些次要人物显得有些脸谱化，呵呵。。。CC版本，3小时38分。。。

### 4152 有用 影志 看过 2015-06-20 18:33:54

极致的美，极致的伤。音乐太灵，画面太精，原来早在1987年，外国导演就早于《活着》《霸王别姬》把20世纪中国历史拍的如此炉火纯青了…“我从未和家人分开过” 额娘，阿嬷，婉容，庄士敦，溥杰，皇宫…溥仪的一生都在告别，跟亲人，跟时代，跟历史，身不由己。@上海国际电影节 4k修复版

> 更多短评 171380条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 末代皇帝的影评 · · · · · · ( 全部 2799 条 )

热门 / 最新 / 好友
静波 2008-12-25 22:19:31

## 末代皇帝：那要命的广角自然光

《末代皇帝》创造了中国影视历史上的好几个第一：第一部在故宫取景的故事片（而非资料片），而且是完全清场移除护栏的取景，后来郑少秋的《戏说乾隆》中，你可以很明显的看到乾隆身后的太和殿正门被铁栏挡住。贝托鲁奇第一次（也是唯一一次）讲述中国的故事。而且，这是关于中... (展开)
10085 259 617回应 收起
Stigrex 2008-01-15 17:54:43

## 张五常的评论

这篇影评可能有剧透

（1988.05.18）评《末代皇帝》 几个月前在美国看了《末代皇帝》，觉得是难得的好戏。后来这部片在香港上映了，各方影评，在称赞中都有所保留。一些评论认为该片不忠于史实，一些认为除了摄影、导演外别无可取，也有一些认为若中国人亲自制作，会拍得更好。对这些评论，我莫名... (展开)
3728 152 391回应 收起
natalie 2006-11-01 00:16:35

## 我们也只是在门外张望

世界那么小，小到我们就像生活在巨大的玻璃缸里，透明的世界，我们彼此遇见。世界那么大，大得有些地方，我们一辈子也无法到达。我们抬头仰望天空，时间向后退去，白云向前飞去。历史是很玄妙的东西，我们在门内，时间在门外流过，不留任何痕迹。我们一直在向门外张望，希望能... (展开)
2002 120 177回应 收起
Bingshu 2008-01-31 21:07:22

## 满宫残照，溥仪的前世今生

［多年前的文，和现在文风差距较大，写得太嫩，大家凑合看看。］ 1950年，东北中苏边境。一群满清战犯被押解安置。 故事从列车的停靠开始，从严寒中，黑压压的政治犯呼吸的霜雾开始，不断闪回，现实与过往交错更替，记忆与生存映照对比，如此还原了一位真实饱满的末代皇帝。 从... (展开)
1215 56 60回应 收起
礼士路西岛秀俊 2017-01-01 00:54:41

## 文化输出的正确姿势

《末代皇帝》拍摄于1987年。1987年是个微妙的年份，中国正处在和西方世界蜜月期的尾巴上头。1987年以后，因为某些众所周知的原因，风向变了，由80年代中期的笑迎八方客变成了选择性吸收。无论如何，像当年那样，为了配合一部电影拍摄而封闭整座紫禁城，连英国女王伊丽莎白二世... (展开)
1063 19 56回应 收起
真味君 2012-11-05 21:56:11

## 对施特拉罗在《末代皇帝》中的色彩应用的探讨

在观看过一系列施特拉罗担当摄影师的作品后，我认为施特拉罗在其绝大多数影片中对色彩的应用都有其强烈的目的性和情感性的，这由摄影师的艺术特性所决定并给影片增色不少。《末代皇帝》是施特拉罗作为摄影师第3次获得奥斯卡摄影奖，影片中的色彩应用保持了施特拉罗的一贯风格，... (展开)
505 10 18回应 收起
知心姐姐卢先生 2010-02-15 15:20:49

## 交织事实与想象的历史隐喻

这篇影评可能有剧透

《末代皇帝》（The Last Emperor）是一部于1987年由英意中三国合拍，著名导演贝尔纳多•贝尔托鲁奇执导，讲述中国近现代历史事件的史诗电影。该片在1988年获得了贝尔格莱德国际电影节第二名、巴黎第13届法国电影凯撒奖最佳外国片、联邦德国电影艺术协会奖和第60届奥斯卡九项... (展开)
464 6 18回应 收起
souvent 2008-05-04 00:30:02

## 再看《末代皇帝》时注意到的十个细节

2022年9月更新： 在ipad上重温片段。 有人同情真好。大部分时候，孤独是永恒的归宿。 老贝对中国人民的感情是真挚的、感人的、隽永的。 他是中国人民的朋友。 2018年4月更新： 《末代皇帝》的转场设计堪称经典，百年呼唤贯穿我们的近代史： open the door！ 大意了，老贝并不险... (展开)
248 32 61回应 收起
蔡鸟 2005-10-23 10:18:47

## painful mostly

如果有一部电影是晚清的“入门”的话，那就是这部The last Emperor.如果有不外文片能够以旁人眼光揭示历史的痛的话，那也是这部电影。溥仪这个“傀儡”的代名词，导演并没有我们通常对他的痛恨，反而是一种无比的同情，就像我们从来不曾考虑过的一样，他其实曾经反抗过，他曾经... (展开)
228 22 24回应 收起
Maverick 2016-07-07 23:25:26

## 《末代皇帝》电影剧本

《末代皇帝》电影剧本 编剧：[英]马克·贝皮罗、[意]贝尔纳多·贝尔托鲁齐 导演：[意]贝尔纳多·贝尔托鲁齐 最近获奥斯卡大奖九项提名 彩色宽银幕立体声故事片 北影继《马可·波罗》后再度与欧洲电影界合作钜制 编者按：据《人民日报》2月17日发自罗马的电讯。记者罗晋标、... (展开)
169 2 3回应 收起

> 更多影评 2799篇

添加新讨论

## 讨论区 · · · · · ·

请教219min清晰的哪里可以看哇~ | 来自E31Q | 14 回应 | 2022-11-23 10:41:46
一部大烂片却被奉为经典 | 来自二脚猫艺术家 | 97 回应 | 2022-11-23 10:27:57
小溥仪和太监玩闭眼抓人游戏没看懂 | 来自豆花鱼 | 10 回应 | 2022-11-21 23:48:59
为啥溥仪在太和殿碰到小红卫兵 | 来自看清前路申研版 | 9 回应 | 2022-11-21 23:22:51
作为亡国之君，溥仪算是运气很好的了。我觉得他并不苦 | 来自特种兵王 | 81 回应 | 2022-11-21 23:18:26

> 去这部影片的讨论区（全部589条）

## 关于《末代皇帝》的问题 · · · · · · ( 全部56个 )

- 婉容撕花瓣、吃花瓣的细节想要表达什么？ 17人回答
- 奶妈是怎么做到一直有奶的？ 11人回答

> 全部56个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 免费观看
- 芒果TV 免费观看
- 哔哩哔哩 免费观看
- 西瓜视频 免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 电影上的“三部曲”系列~~ (Black Tulip)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)
- 奥斯卡最佳影片 (Boward)
- 电影纪录你们的脸 (麦子)

## 谁在看这部电影 · · · · · ·

- 白马过平川
  6分钟前 看过
- cyndy
  8分钟前 看过
- 大葱
  9分钟前 想看

1342935人看过 / 426515人想看

订阅末代皇帝的评论:
feed: rss 2.0